@@ -101,7 +101,7 @@ get_reason_for_error (const char *dbus_error)
 	if (g_str_equal (dbus_error, "net.reactivated.Fprint.Error.AlreadyInUse"))
 		return N_("The device is already in use.");
 	if (g_str_equal (dbus_error, "net.reactivated.Fprint.Error.Internal"))
-		return N_("An internal error occured");
+		return N_("An internal error occurred");
 
 	return NULL;
 }
@@ -219,10 +219,10 @@ delete_fingerprints_question (GtkBuilder *dialog, GtkWidget *enable, GtkWidget *
 					   GTK_MESSAGE_QUESTION,
 					   GTK_BUTTONS_NONE,
 					   _("Delete registered fingerprints?"));
-	gtk_dialog_add_button (GTK_DIALOG (question), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (question), "gtk-cancel", GTK_RESPONSE_CANCEL);
 
 	button = gtk_button_new_with_mnemonic (_("_Delete Fingerprints"));
-	gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_stock (GTK_STOCK_DELETE, GTK_ICON_SIZE_BUTTON));
+	gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name ("edit-delete", GTK_ICON_SIZE_BUTTON));
 	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 	gtk_dialog_add_action_widget (GTK_DIALOG (question), button, GTK_RESPONSE_OK);
