@@ -211,28 +211,25 @@ nameplate_tile_setup (NameplateTile *this)
 	NameplateTilePrivate *priv = NAMEPLATE_TILE_GET_PRIVATE (this);
 
 	GtkWidget *hbox;
-	GtkWidget *alignment;
 	GtkWidget *vbox;
 
-	priv->image_ctnr = GTK_CONTAINER (gtk_alignment_new (0.5, 0.5, 1.0, 1.0));
-	priv->header_ctnr = GTK_CONTAINER (gtk_alignment_new (0.0, 0.5, 1.0, 1.0));
-	priv->subheader_ctnr = GTK_CONTAINER (gtk_alignment_new (0.0, 0.5, 1.0, 1.0));
+	priv->image_ctnr = GTK_CONTAINER (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
+	gtk_widget_set_valign (GTK_WIDGET (priv->image_ctnr), GTK_ALIGN_CENTER);
+
+	priv->header_ctnr = GTK_CONTAINER (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
+
+	priv->subheader_ctnr = GTK_CONTAINER (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
+	gtk_widget_set_halign (GTK_WIDGET (priv->subheader_ctnr), GTK_ALIGN_START);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-	hbox = gtk_hbox_new (FALSE, 6);
-	vbox = gtk_vbox_new (FALSE, 0);
-#endif
-
-	alignment = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
+	gtk_widget_set_halign (vbox, GTK_ALIGN_FILL);
+	gtk_widget_set_valign (vbox, GTK_ALIGN_CENTER);
 
 	gtk_container_add (GTK_CONTAINER (this), hbox);
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (priv->image_ctnr), FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), alignment, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-	gtk_container_add (GTK_CONTAINER (alignment), vbox);
 	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (priv->header_ctnr), FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (priv->subheader_ctnr), FALSE, FALSE, 0);
 
@@ -245,7 +242,7 @@ nameplate_tile_setup (NameplateTile *this)
 	if (GTK_IS_WIDGET (this->subheader))
 		gtk_container_add (priv->subheader_ctnr, this->subheader);
 
-	gtk_button_set_focus_on_click (GTK_BUTTON (this), FALSE);
+	gtk_widget_set_focus_on_click (GTK_WIDGET (this), FALSE);
 }
 
 static void
@@ -253,9 +250,7 @@ nameplate_tile_drag_begin (GtkWidget * widget, GdkDragContext * context)
 {
 	NameplateTile *this = NAMEPLATE_TILE (widget);
 	GtkImage *image;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	const gchar *name;
-#endif
 
 	(*GTK_WIDGET_CLASS (nameplate_tile_parent_class)->drag_begin) (widget, context);
 
@@ -264,7 +259,6 @@ nameplate_tile_drag_begin (GtkWidget * widget, GdkDragContext * context)
 
 	image = GTK_IMAGE (this->image);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	switch (gtk_image_get_storage_type (image))
 	{
 	case GTK_IMAGE_PIXBUF:
@@ -283,23 +277,4 @@ nameplate_tile_drag_begin (GtkWidget * widget, GdkDragContext * context)
 	default:
 		break;
 	}
-#else
-	switch (image->storage_type)
-	{
-	case GTK_IMAGE_PIXBUF:
-		if (image->data.pixbuf.pixbuf)
-			gtk_drag_set_icon_pixbuf (context, image->data.pixbuf.pixbuf, 0, 0);
-
-		break;
-
-	case GTK_IMAGE_ICON_NAME:
-		if (image->data.name.pixbuf)
-			gtk_drag_set_icon_pixbuf (context, image->data.name.pixbuf, 0, 0);
-
-		break;
-
-	default:
-		break;
-	}
-#endif
 }
